@@ -71,6 +71,8 @@ enum MusicContextType
 	MUSIC_CONTEXT_SUMMER,
 	MUSIC_CONTEXT_AUTUMN,
 	MUSIC_CONTEXT_WINTER,
+	MUSIC_CONTEXT_EXCLUSIVE_MAIN,
+	MUSIC_CONTEXT_EXCLUSIVE_TITLE,
 	MUSIC_CONTEXTNUM,
 	MUSIC_CONTEXT_NONE=-1
 };
